summaryrefslogtreecommitdiffstats
path: root/juk/tageditor.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:25 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:25 -0600
commitf59dfa08651a47f21d004e8e4cb5020b8035287e (patch)
tree0582273566661474af14fe8f1737cfe1e6527d46 /juk/tageditor.h
parent83fbc82a101309e171089f0d5ed080f82a367345 (diff)
downloadtdemultimedia-f59dfa08651a47f21d004e8e4cb5020b8035287e.tar.gz
tdemultimedia-f59dfa08651a47f21d004e8e4cb5020b8035287e.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 83fbc82a101309e171089f0d5ed080f82a367345.
Diffstat (limited to 'juk/tageditor.h')
-rw-r--r--juk/tageditor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/juk/tageditor.h b/juk/tageditor.h
index 10649494..35526380 100644
--- a/juk/tageditor.h
+++ b/juk/tageditor.h
@@ -67,10 +67,10 @@ private:
void save(const PlaylistItemList &list);
void saveChangesPrompt();
/**
* Adds an item to JuK's tagging layout. This handles the creation and
* placement of the "enable" box as well.
*/
- void addItem(const TQString &text, TQWidget *item, TQBoxLayout *layout, const TQString &iconName = TQString());
+ void addItem(const TQString &text, TQWidget *item, TQBoxLayout *tqlayout, const TQString &iconName = TQString());
/**
* Adds a widget to m_hideList and returns that widget.
@@ -67,10 +67,10 @@ private:
void saveChangesPrompt();
/**
- * Adds an item to JuK's tagging layout. This handles the creation and
+ * Adds an item to JuK's tagging tqlayout. This handles the creation and
* placement of the "enable" box as well.
*/